<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>AllFields</name>
    <message>
        <location filename="../details.cpp" line="627"/>
        <source>Field</source>
        <translation>Kenttä</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="627"/>
        <source>Field name</source>
        <translation>Kentän nimi</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="628"/>
        <source>Description</source>
        <translation>Kuvaus</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="628"/>
        <source>Field description</source>
        <translation>Kentän kuvaus</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="629"/>
        <source>Value</source>
        <translation>Arvo</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="629"/>
        <source>Field value</source>
        <translation>Kentän arvo</translation>
    </message>
</context>
<context>
    <name>Boxvar</name>
    <message>
        <location filename="../prefs.cpp" line="59"/>
        <source>Exit on closing</source>
        <translation>Poistu suljettaessa</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="60"/>
        <source>Remember Position</source>
        <translation>Muista sijainti</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="68"/>
        <source>Host Name Lookup</source>
        <translation>Palvelinnimihaku</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="69"/>
        <source>Service Name Lookup</source>
        <translation>Palvelunimihaku</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="75"/>
        <source>Disclosure Triangles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="76"/>
        <source>Branch Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="82"/>
        <source>Auto Save Settings on Exit</source>
        <translation>Tallenna asetukset poistuessa</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="83"/>
        <source>Selection: Copy PIDs to Clipboard</source>
        <translation>Valinta: Kopioi PID leikepöydälle</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="85"/>
        <source>Normalize NICE</source>
        <translation>Normalisoi prioriteetti</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="86"/>
        <source>Use pmap for Map Names</source>
        <translation>Nimeä kartat käyttämällä pmap</translation>
    </message>
</context>
<context>
    <name>Cbgroup</name>
    <message>
        <location filename="../prefs.cpp" line="106"/>
        <source>General</source>
        <translation>Yleiset</translation>
    </message>
</context>
<context>
    <name>ControlBar</name>
    <message>
        <location filename="../misc.cpp" line="634"/>
        <source>Linear</source>
        <translation>Lista</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="637"/>
        <source>Tree</source>
        <translation>Puu</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="646"/>
        <source>Thread</source>
        <translation>Säikeet</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="653"/>
        <source>All Processes</source>
        <translation>Kaikki prosessit</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="654"/>
        <source>Your Processes</source>
        <translation>Omat prosessit</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="655"/>
        <source>Non-Root Processes</source>
        <translation>Ei pääkäyttäjän prosesseja</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="656"/>
        <source>Running Processes</source>
        <translation>Käynnissä olevat prosessit</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="672"/>
        <source>Pause (Ctrl+Space)</source>
        <translation>Tauko (Ctrl+Välilyönti)</translation>
    </message>
</context>
<context>
    <name>Details</name>
    <message>
        <location filename="../details.cpp" line="36"/>
        <source>Process %1 ( %2 ) - details</source>
        <translation>Prosessi %1 ( %2 ) - tarkat tiedot</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="45"/>
        <source>Files</source>
        <translation>Tiedostot</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="54"/>
        <source>Sockets</source>
        <translation>Pistokkeet</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="59"/>
        <source>Memory Maps</source>
        <translation>Muistikartoitukset</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="61"/>
        <source>Environment</source>
        <translation>Ympäristö</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="62"/>
        <source>All Fields</source>
        <translation>Kaikki kentät</translation>
    </message>
</context>
<context>
    <name>Environ</name>
    <message>
        <location filename="../details.cpp" line="579"/>
        <source>Variable</source>
        <translation>Muuttuja</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="579"/>
        <source>Variable name</source>
        <translation>Muuttujan nimi</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="580"/>
        <source>Value</source>
        <translation>Arvo</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="580"/>
        <source>Variable value</source>
        <translation>Muuttujan arvo</translation>
    </message>
</context>
<context>
    <name>FieldSelect</name>
    <message>
        <location filename="../fieldsel.cpp" line="34"/>
        <source>Select Custom Fields </source>
        <translation>Valitse kentät </translation>
    </message>
    <message>
        <location filename="../fieldsel.cpp" line="75"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
</context>
<context>
    <name>Files</name>
    <message>
        <location filename="../details.cpp" line="495"/>
        <source>Fd</source>
        <translation>Fd</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="495"/>
        <source>File descriptor</source>
        <translation>Tiedostokuvaaja</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="497"/>
        <source>Mode</source>
        <translation>Tila</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="497"/>
        <source>Open mode</source>
        <translation>Avaustila</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="499"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="499"/>
        <source>File name (if available)</source>
        <translation>Tiedostonimi (jos saatavilla)</translation>
    </message>
</context>
<context>
    <name>IO_Graph</name>
    <message>
        <location filename="../infobar.cpp" line="785"/>
        <source>I/O Summary:</source>
        <translation>I/O-yhteenveto:</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="819"/>
        <source>No input or output</source>
        <translation>Ei vastaanotettua tai lähetettyä dataa</translation>
    </message>
</context>
<context>
    <name>IntervalDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="43"/>
        <source>Change Update Period</source>
        <translation>Muuta päivitysnopeus</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="49"/>
        <source>New Update Period</source>
        <translation>Uusi päivitysnopeus</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="85"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="87"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="121"/>
        <source>No UPDATE</source>
        <translation>Keskeytä päivitys</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="139"/>
        <source>Invalid value</source>
        <translation>Virheellinen arvo</translation>
    </message>
</context>
<context>
    <name>Maps</name>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Address Range</source>
        <translation>Osoitealue</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Mapped addresses (hex) )</source>
        <translation>Kartoitetut osoitteet (hex)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Kbytes mapped (dec)</source>
        <translation>kt kartoitettuja (dec)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Perm</source>
        <translation>Oikeudet</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Permission flags</source>
        <translation>Käyttöoikeusliput</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>Offset</source>
        <translation>Siirtymä</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>File offset at start of mapping (hex)</source>
        <translation>Tiedoston siirtymä kartoituksen alkupäässä (hex)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Device</source>
        <translation>Laite</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Major,Minor device numbers (dec)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode</source>
        <translation>Inode</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode number (dec)</source>
        <translation>Inode-numero (dec)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File</source>
        <translation>Tiedosto</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File name (if available)</source>
        <translation>Tiedostonimi (jos saatavilla)</translation>
    </message>
</context>
<context>
    <name>PermissionDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="264"/>
        <source>Permission</source>
        <translation>Käyttöoikeudet</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="273"/>
        <source>Root password</source>
        <translation>Pääkäyttäjän salasana</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="280"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="283"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../prefs.cpp" line="150"/>
        <source>Preferences</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="157"/>
        <source>Setting</source>
        <translation type="unfinished">Asetus</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="191"/>
        <source>%CPU divided by</source>
        <translation>%CPU jakoluku</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="198"/>
        <source>Total cpu: %1</source>
        <translation>Kokonaismäärä CPU:ita: %1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="199"/>
        <source>Single cpu: 1</source>
        <translation>Yksittäisiä CPU:ita: 1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="205"/>
        <source>default</source>
        <translation>oletus</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="206"/>
        <source>for developer</source>
        <translation>kehittäjälle</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="240"/>
        <source>Appearance</source>
        <translation>Ulkoasu</translation>
    </message>
</context>
<context>
    <name>Proc</name>
    <message>
        <location filename="../proc.cpp" line="2615"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2615"/>
        <source>Process ID</source>
        <translation>Prosessitunnus</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2617"/>
        <source>TGID</source>
        <translation>TGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2617"/>
        <source>Task group ID ( parent of threads )</source>
        <translation type="unfinished">Tehtäväryhmätunnus ( säikeiden vanhempi )</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2619"/>
        <source>PPID</source>
        <translation>PPID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2619"/>
        <source>Parent process ID</source>
        <translation>Vanhemman prosessitunnus</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2621"/>
        <source>PGID</source>
        <translation>PGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2621"/>
        <source>Process group ID</source>
        <translation>Prosessin ryhmätunnus</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2623"/>
        <source>SID</source>
        <translation>SID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2623"/>
        <source>Session ID</source>
        <translation>Istunnon tunnus</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2625"/>
        <source>TTY</source>
        <translation>TTY</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2625"/>
        <source>Terminal</source>
        <translation>Pääte</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2627"/>
        <source>TPGID</source>
        <translation>TPGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2627"/>
        <source>Process group ID of tty owner</source>
        <translation>Prosessin ryhmätunnus päätteen omistajalle</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2629"/>
        <source>USER</source>
        <translation>KÄYTTÄJÄ</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2629"/>
        <source>Owner (*=suid root, +=suid a user)</source>
        <translation>Omistaja (*=suid pääkäyttäjälle, +=suid käyttäjälle)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2631"/>
        <source>GROUP</source>
        <translation>RYHMÄ</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2631"/>
        <source>Group name (*=sgid other)</source>
        <translation>Ryhmän nimi (*=sgid muille)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2633"/>
        <source>UID</source>
        <translation>UID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2633"/>
        <source>Real user ID</source>
        <translation>Oikea käyttäjätunniste</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2635"/>
        <source>EUID</source>
        <translation>EUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2635"/>
        <source>Effective user ID</source>
        <translation>Käytännön käyttäjätunniste</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2637"/>
        <source>SUID</source>
        <translation>SUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2637"/>
        <source>Saved user ID (Posix)</source>
        <translation>Tallennettu käyttäjätunniste (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2639"/>
        <source>FSUID</source>
        <translation>FSUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2639"/>
        <source>File system user ID</source>
        <translation>Käyttäjätunniste tiedostojärjestelmässä</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2641"/>
        <source>GID</source>
        <translation>GID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2641"/>
        <source>Real group ID</source>
        <translation>Oikea ryhmätunniste</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2643"/>
        <source>EGID</source>
        <translation>EGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2643"/>
        <source>Effective group ID</source>
        <translation>Käytännön ryhmätunniste</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2645"/>
        <source>SGID</source>
        <translation>SGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2645"/>
        <source>Saved group ID (Posix)</source>
        <translation>Tallennettu ryhmätunniste (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2647"/>
        <source>FSGID</source>
        <translation>FSGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2647"/>
        <source>File system group ID</source>
        <translation>Ryhmätunniste tiedostojärjestelmässä</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2649"/>
        <source>PRI</source>
        <translation>PRI</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2649"/>
        <source>Dynamic priority</source>
        <translation>Dynaaminen prioriteetti</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2651"/>
        <source>NICE</source>
        <translation>NICE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2651"/>
        <source>Scheduling favour (higher -&gt; less cpu time)</source>
        <translation>Vuoronnussuosio (korkeampi -&gt; vähemmän CPU-aikaa)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2653"/>
        <source>NLWP</source>
        <translation>NLWP</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2653"/>
        <source>Number of tasks(threads) in task group</source>
        <translation>Tehtävät (säikeet) tehtäväryhmässä</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2655"/>
        <source>PLCY</source>
        <translation>PLCY</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2655"/>
        <source>Scheduling policy</source>
        <translation>Vuoronnuskäytäntö</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2657"/>
        <source>RPRI</source>
        <translation>RPRI</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2657"/>
        <source>Realtime priority (0-99, more is better)</source>
        <translation>Reaaliaikainen prioriteetti (0-99, korkeampi parempi)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2659"/>
        <source>TMS</source>
        <translation>TMS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2659"/>
        <source>Time slice in milliseconds</source>
        <translation>Aika-annos millisekunneissa</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2661"/>
        <source>%SAVG</source>
        <translation>%SAVG</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2661"/>
        <source>Percentage average sleep time (-1 -&gt; N/A)</source>
        <translation>Keskimääräinen lepoaika prosentteina (-1 -&gt; N/A)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2663"/>
        <source>CPUSET</source>
        <translation>CPUSET</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2663"/>
        <source>Affinity CPU mask (0 -&gt; API not supported)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2665"/>
        <source>MAJFLT</source>
        <translation>MAJFLT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2665"/>
        <source>Number of major faults (disk access)</source>
        <translation>Suurten vikojen määrä (levyn käyttö)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2667"/>
        <source>MINFLT</source>
        <translation>MINFLT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2667"/>
        <source>Number of minor faults (no disk access)</source>
        <translation>Pienten vikojen määrä (ei levyn käyttöä)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2670"/>
        <source>VSIZE</source>
        <translation>VSIZE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2670"/>
        <source>Virtual image size of process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2672"/>
        <source>RSS</source>
        <translation>RSS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2672"/>
        <source>Resident set size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2674"/>
        <source>MEM</source>
        <translation>MEM</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2674"/>
        <source>memory usage (RSS-SHARE)</source>
        <translation>muistin käyttö (RSS-SHARE)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2676"/>
        <source>TRS</source>
        <translation>TRS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2676"/>
        <source>Text(code) resident set size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2678"/>
        <source>DRS</source>
        <translation>DRS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2678"/>
        <source>Data resident set size(malloc+global variable)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2680"/>
        <source>STACK</source>
        <translation>STACK</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2680"/>
        <source>Stack size</source>
        <translation>Pinon koko</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2682"/>
        <source>SHARE</source>
        <translation>SHARE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2682"/>
        <source>Shared memory with other libs</source>
        <translation>Kirjastojen kesken jaettu muisti</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2684"/>
        <source>SWAP</source>
        <translation>SWAP</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2684"/>
        <source>Kbytes on swap device</source>
        <translation>kt:a sivutuslaitteessa</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2686"/>
        <source>IO_R</source>
        <translation>IO_R</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2686"/>
        <source>io read (file)</source>
        <translation>io-luku (tiedosto)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2688"/>
        <source>IO_W</source>
        <translation>IO_W</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2688"/>
        <source>io write (file)</source>
        <translation type="unfinished">io-kirjoitus (tiedosto)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2690"/>
        <source>DT</source>
        <translation>DT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2690"/>
        <source>Number of dirty (non-written) pages</source>
        <translation>Likaisten (ei-kirjoitettujen) sivujen määrä</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2692"/>
        <source>STAT</source>
        <translation>STAT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2692"/>
        <source>State of the process </source>
        <translation>Prosessin tila </translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2694"/>
        <source>FLAGS</source>
        <translation>FLAGS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2694"/>
        <source>Process flags (hex)</source>
        <translation>Prosessin liput (hex)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2696"/>
        <source>WCHAN</source>
        <translation>WCHAN</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2696"/>
        <source>Kernel function where process is sleeping</source>
        <translation>Ytimen funktio, jossa prosessi lepäilee</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2698"/>
        <source>%WCPU</source>
        <translation>%WCPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2698"/>
        <source>Weighted percentage of CPU (30 s average)</source>
        <translation type="unfinished">CPU:n painotettu prosenttiosuus (keskimäärin 30s)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2700"/>
        <source>%CPU</source>
        <translation>%CPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2700"/>
        <source>Percentage of CPU used since last update</source>
        <translation>Prosessorin käyttö prosentteina viimeisestä päivityksestä</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2702"/>
        <source>%MEM</source>
        <translation>%MEM</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2702"/>
        <source>Percentage of memory used (RSS/total mem)</source>
        <translation>Muistin käyttö prosentteina (RSS/kokonaismuisti)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2704"/>
        <source>START</source>
        <translation>START</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2704"/>
        <source>Time process started</source>
        <translation>Kellonaika, milloin prosessi käynnistyi</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2706"/>
        <source>TIME</source>
        <translation>TIME</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2706"/>
        <source>Total CPU time used since start</source>
        <translation>Prosessorin aikaa kokonaisuudessaan käytetty käynnistyksestä alkaen</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2708"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2708"/>
        <source>CPU the process is executing on (SMP system)</source>
        <translation>Prosessin käyttämä prosessori (SMP-järjestelmä)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2710"/>
        <source>the process name</source>
        <translation>prosessin nimi</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2710"/>
        <source>Process Name</source>
        <translation>Prosessin nimi</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2714"/>
        <source>CWD</source>
        <translation>CWD</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2714"/>
        <source>Current working directory</source>
        <translation>Nykyinen työhakemisto</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2715"/>
        <source>ROOT</source>
        <translation>ROOT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2715"/>
        <source>Root directory of process</source>
        <translation>Prosessin juurikansio</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2718"/>
        <source>COMMAND_LINE</source>
        <translation>COMMAND_LINE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2718"/>
        <source>Command line that started the process</source>
        <translation>Prosessin käynnistänyt komentorivi</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../qps.cpp" line="1618"/>
        <source>Show</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1621"/>
        <source>Hide</source>
        <translation>Piilota</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1626"/>
        <source>Quit</source>
        <translation>Lopeta</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="430"/>
        <location filename="../infobar.cpp" line="437"/>
        <source>User: </source>
        <translation>Käyttäjä: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="431"/>
        <location filename="../infobar.cpp" line="438"/>
        <source>System: </source>
        <translation>Järjestelmä: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="432"/>
        <location filename="../infobar.cpp" line="439"/>
        <source>Nice: </source>
        <translation>Prioriteetti: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="430"/>
        <location filename="../infobar.cpp" line="431"/>
        <location filename="../infobar.cpp" line="432"/>
        <location filename="../infobar.cpp" line="437"/>
        <location filename="../infobar.cpp" line="438"/>
        <location filename="../infobar.cpp" line="439"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="474"/>
        <location filename="../infobar.cpp" line="509"/>
        <source>Total: </source>
        <translation>Kaikki: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="477"/>
        <location filename="../infobar.cpp" line="515"/>
        <source>Used: </source>
        <translation>Käytetty: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="481"/>
        <source>Cached: </source>
        <translation>Välimuistissa: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="484"/>
        <source>Buffer: </source>
        <translation>Puskuri: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="512"/>
        <source>Free: </source>
        <translation>Vapaana: </translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="554"/>
        <source>Time passed after system boot</source>
        <translation>Järjestelmän käynnistyksestä kulunut aika</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="582"/>
        <source>Average CPU load each 1, 5 ,15 minutes</source>
        <translation>Keskimääräinen prosessorikuormitus joka 1, 5, 15 minuutti</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="727"/>
        <source>CPU Usage Summary:</source>
        <translation>Prosessorikäytön tilastot:</translation>
    </message>
</context>
<context>
    <name>Qps</name>
    <message>
        <location filename="../qps.cpp" line="171"/>
        <source>header_popup</source>
        <translation> </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="172"/>
        <source>Remove Field</source>
        <translation>Poista kenttä</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="173"/>
        <source>Add Field</source>
        <translation>Lisää kenttä</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="176"/>
        <source>Session</source>
        <translation>Istunto</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="180"/>
        <source>View</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="181"/>
        <source>Process</source>
        <translation>Prosessi</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="182"/>
        <source>Log</source>
        <translation>Loki</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="187"/>
        <source>Fields</source>
        <translation>Kentät</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="188"/>
        <source>Custom Fields</source>
        <translation>Omat kentät</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="190"/>
        <source>Basic Fields </source>
        <translation>Peruskentät </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="192"/>
        <source>Jobs Fields </source>
        <translation>Työkentät </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="194"/>
        <source>Memory Fields </source>
        <translation>Muistikentät </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="197"/>
        <source>Scheduling Fields </source>
        <translation>Vuoronnuskentät </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="214"/>
        <source>Select Custom Fields...</source>
        <translation>Valitse omat kentät...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="223"/>
        <source>Options</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="224"/>
        <source>Update Period...</source>
        <translation>Päivitysnopeus...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="233"/>
        <source>Show Status bar</source>
        <translation>Näytä tilarivi</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="242"/>
        <source>Preferences...</source>
        <translation>Asetukset...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="248"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="249"/>
        <location filename="../qps.cpp" line="1666"/>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="335"/>
        <source>test</source>
        <translation>testaus</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="336"/>
        <source>Copied to Clipboard</source>
        <translation>Kopioitu leikepöydälle</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="388"/>
        <source>context popup</source>
        <translation>kontekstivalikko</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="389"/>
        <source>Renice...</source>
        <translation>Muuta prioriteetti...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="390"/>
        <source>Scheduling...</source>
        <translation>Vuoronnus...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="392"/>
        <source>Terminate</source>
        <translation>Lopeta</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="393"/>
        <source>Hangup</source>
        <translation>Katkaise yhteys virtuaalipäätteeseen</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="394"/>
        <source>Kill</source>
        <translation>Tapa</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="395"/>
        <source>Stop</source>
        <translation>Pysäytä</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="397"/>
        <source>Continue</source>
        <translation>Jatka</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="400"/>
        <source>Other Signals</source>
        <translation>Muut signaalit</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="401"/>
        <source>SIGINT (interrupt)</source>
        <translation>SIGINT (keskeytä)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="403"/>
        <source>SIGCONT (continue)</source>
        <translation>SIGCONT (jatka)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="405"/>
        <source>SIGSTOP (stop)</source>
        <translation>SIGSTOP (pysäytä)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="407"/>
        <source>SIGQUIT (quit)</source>
        <translation>SIGQUIT (lopeta ja tulosta ydin)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="409"/>
        <source>SIGILL (illegal instruction)</source>
        <translation>SIGILL (laiton käsky)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="411"/>
        <source>SIGABRT (abort)</source>
        <translation>SIGABRT (keskeytys)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="413"/>
        <source>SIGFPE (floating point exception)</source>
        <translation>SIGFPE (liukulukupoikkeus)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="415"/>
        <source>SIGSEGV (segmentation violation)</source>
        <translation>SIGSEGV (segmentointirikkomus)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="417"/>
        <source>SIGPIPE (broken pipe)</source>
        <translation>SIGPIPE (hajonnut putki)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="419"/>
        <source>SIGALRM (timer signal)</source>
        <translation>SIGALRM (aikaraja saavutettu)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="421"/>
        <source>SIGUSR1 (user-defined 1)</source>
        <translation>SIGUSR1 (käyttäjämääritetty 1)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="423"/>
        <source>SIGUSR2 (user-defined 2)</source>
        <translation>SIGUSR2 (käyttäjämääritetty 2)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="425"/>
        <source>SIGCHLD (child death)</source>
        <translation>SIGCHLD (lapsiprosessin tilamuutos)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="427"/>
        <source>SIGTSTP (stop from tty)</source>
        <translation>SIGTSTP (päätepysäytys)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="429"/>
        <source>SIGTTIN (tty input)</source>
        <translation>SIGTTIN (päätesyöttö)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="431"/>
        <source>SIGTTOU (tty output)</source>
        <translation>SIGTTOU (päätetulostus)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="438"/>
        <source>View Details</source>
        <translation>Näytä lisätiedot</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="676"/>
        <source>Show File Path</source>
        <translation>Näytä tiedoston polku</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="682"/>
        <source>Show Graph</source>
        <translation>Näytä kaavio</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="688"/>
        <source>Show Control Bar</source>
        <translation>Näytä ohjausrivi</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="699"/>
        <source>Include Child Times</source>
        <translation>Sisällytä lapsiajat</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="287"/>
        <source>Quit</source>
        <translation>Lopeta</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1144"/>
        <location filename="../qps.cpp" line="1175"/>
        <location filename="../qps.cpp" line="1182"/>
        <location filename="../qps.cpp" line="1203"/>
        <location filename="../qps.cpp" line="1237"/>
        <location filename="../qps.cpp" line="1332"/>
        <source>Permission denied</source>
        <translation>Lupa evätty</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1145"/>
        <source>You do not have permission to renice the selected processes. Only the process owner and the super-user are allowed to do that.</source>
        <translation>Käyttöoikeutesi eivät riitä muuttamaan prioriteettia valituille prosesseille. Vain prosessin omistaja ja pääkäyttäjä voivat tehdä niin.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1176"/>
        <source>You do not have permission to renice process %1 (%2).Only the process owner and the super-user are allowed to do that.</source>
        <translation>Käyttöoikeutesi eivät riitä muuttamaan prioriteettia prosessille %1 (%2). Vain prosessin omistaja ja pääkäyttäjä voivat tehdä niin.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1183"/>
        <source>Only the super-user may lower the nice value of a process.</source>
        <translation>Vain pääkäyttäjä voi alentaa prosessin prioriteettia.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1204"/>
        <source>Only the super-user may change the scheduling policy and static priority.</source>
        <translation>Vain pääkäyttäjä voi muuttaa vuoronnuskäytäntöä ja pysyvää prioriteettia.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1238"/>
        <source>You do not have permission to change the scheduling and/or priority of process %1 (%2). Only the super-user may do that.</source>
        <translation>Käyttöoikeutesi eivät riitä muuttamaan vuoronnusta ja/tai prioriteettia prosessille %1 (%2). Vain pääkäyttäjä voi tehdä niin.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1299"/>
        <source>Do you really want to terminate the selected process(es)?</source>
        <translation>Haluatko varmasti lopettaa valitut prosessit?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1301"/>
        <source>Do you really want to hang up the selected process(es)?</source>
        <translation>Haluatko varmasti katkaista valittujen prosessien yhteys virtuaalipäätteisiinsä?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1303"/>
        <source>Do you really want to kill the selected process(es)?</source>
        <translation>Haluatko varmasti tappaa valitut prosessit?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1312"/>
        <source>Question</source>
        <translation>Kysymys</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1333"/>
        <source>You do not have permission to send a signal to process %1 (%2). Only the super-user and the owner of the process may send signals to it.</source>
        <translation>Käyttöoikeutesi eivät riitä lähettämään signaalia prosessille %1 (%2). Vain prosessin omistaja ja pääkäyttäjä voivat tehdä sen.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1682"/>
        <source>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1684"/>
        <source>&lt;h2&gt; Qps %1 - A Visual Process Manager &lt;/h2&gt; %2 using Qt library %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Source: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Bugtracker: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</source>
        <translation>&lt;h2&gt; Qps %1 - graafinen prosessinhallintaohjelma &lt;/h2&gt; %2 käyttäen Qt %3-kirjastoa&lt;br&gt;&lt;br&gt;&lt;b&gt;Source: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Vianseurantajärjestelmä: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1704"/>
        <source>&lt;b&gt;Original Qps by&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Contributors&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</source>
        <translation>&lt;b&gt;Alkuperäisen Qps:n teki&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Kehittäjät&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</translation>
    </message>
</context>
<context>
    <name>SchedDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>Change scheduling</source>
        <translation>Muuta vuoronnusta</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="296"/>
        <source>Scheduling Policy</source>
        <translation>Vuoronnuskäytäntö</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="298"/>
        <source>SCHED_OTHER (time-sharing)</source>
        <translation>SCHED_OTHER (osituskäyttö)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="299"/>
        <source>SCHED_FIFO (real-time)</source>
        <translation>SCHED_FIFO (reaaliaikainen)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="300"/>
        <source>SCHED_RR (real-time)</source>
        <translation>SCHED_RR (reaaliaikainen)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="314"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="316"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="346"/>
        <source>Priority (1-99):</source>
        <translation>Prioriteetti (1-99):</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="379"/>
        <source>Invalid Input</source>
        <translation>Virheellinen arvo</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="380"/>
        <source>The priority must be in the range 1..99</source>
        <translation>Sallitut arvot ovat 1..99</translation>
    </message>
</context>
<context>
    <name>SearchBox</name>
    <message>
        <location filename="../misc.cpp" line="588"/>
        <source>PID, COMMAND, USER...</source>
        <translation>PID, KOMENTO, KÄYTTÄJÄ...</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="589"/>
        <source>Filter</source>
        <translation>Suodata</translation>
    </message>
</context>
<context>
    <name>SliderDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="179"/>
        <source>Renice Process</source>
        <translation>Prosessin prioriteetti</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="185"/>
        <source>New nice value:</source>
        <translation>Uusi prioriteetti:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="225"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="229"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>Sockets</name>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>Fd</source>
        <translation>Fd</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>File descriptor</source>
        <translation>Tiedostokuvaaja</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Proto</source>
        <translation>Proto.</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Protocol (TCP or UDP)</source>
        <translation>Protokolla (TCP tai UDP)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Recv-Q</source>
        <translation type="unfinished">Recv-Q</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Bytes in receive queue</source>
        <translation>Tavua vastaanottojonossa</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Send-Q</source>
        <translation type="unfinished">Send-Q</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Bytes in send queue</source>
        <translation>Tavua lähetysjonossa</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local Addr</source>
        <translation>Paikallinen os.</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local IP address</source>
        <translation>Paikallinen IP-osoite</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <location filename="../details.cpp" line="154"/>
        <source>Port</source>
        <translation>Portti</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <source>Local port</source>
        <translation>Paikallinen portti</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote Addr</source>
        <translation>Etäosoite</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote IP address</source>
        <translation>Etä-IP-osoite</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="154"/>
        <source>Remote port</source>
        <translation>Etäportti</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>State</source>
        <translation>Tila</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>Connection state</source>
        <translation>Yhteyden tila</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../misc.cpp" line="624"/>
        <source>Process count: %1</source>
        <translation>Prosesseja: %1</translation>
    </message>
</context>
<context>
    <name>TBloon</name>
    <message>
        <location filename="../misc.cpp" line="343"/>
        <source> This is unstable Alpha feature
 You maybe see a SEGFAULT...</source>
        <translation> Tämä on epävakaa alfa-toiminto
 Saatat nähdä SEGFAULT-virheitä...</translation>
    </message>
</context>
<context>
    <name>UFrame</name>
    <message>
        <location filename="../misc.cpp" line="485"/>
        <source>title</source>
        <translation>otsikko</translation>
    </message>
</context>
</TS>
